@@ -1,8 +1,7 @@
-from copy import copy
-
 from django import template
 from django.conf import settings
 from django.core.urlresolvers import RegexURLResolver, Resolver404
+from django.template import RequestContext
 from django.utils.encoding import smart_str
 
 from preferences import preferences
@@ -81,12 +80,12 @@ def resolve_banner(request, position):
     
 @register.inclusion_tag('banner/inclusion_tags/banner_wide_gizmo.html', takes_context=True)
 def banner_wide_gizmo(context):
-    context = copy(context)
-    context.update({'object': resolve_banner(context['request'], position=context['gizmo_slot_name'])})
+    context = RequestContext(context['request'], {
+        'object': resolve_banner(context['request'], position=context['gizmo_slot_name'])})
     return context
 
 @register.inclusion_tag('banner/inclusion_tags/banner_block_gizmo.html', takes_context=True)
 def banner_block_gizmo(context):
-    context = copy(context)
-    context.update({'object': resolve_banner(context['request'], position=context['gizmo_slot_name'])})
+    context = RequestContext(context['request'], {
+        'object': resolve_banner(context['request'], position=context['gizmo_slot_name'])})
     return context
